@@ -4,4 +4,4 @@ Stores
 
 Stores are persistence components for Documents.  Typically, they can act as either a Connector or a Sink
 """
-from .stores import JsonDocumentStore, TableDataStore, DictDataStore, DataStoreHelper
+from .stores import JsonDocumentStore, TableDataStore, DictDataStore, DataStoreHelper, LocalDocumentStore
